
http://twisted-hl7.readthedocs.org/


Setup environment::

    make env

Run tests (via twisted's trial)::

    make tests


.. image::
   https://travis-ci.org/johnpaulett/twisted-hl7.png
   :target: https://travis-ci.org/johnpaulett/twisted-hl7
